@@ -1,64 +1,89 @@
 from . import processors
 from .discord import *
 from .internal import *
+from .base import *
 
 __all__ = (
-    "RawGatewayEvent",
-    "ChannelCreate",
-    "ChannelUpdate",
-    "ChannelDelete",
-    "ChannelPinsUpdate",
-    "ThreadCreate",
-    "ThreadUpdate",
-    "ThreadDelete",
-    "ThreadListSync",
-    "ThreadMemberUpdate",
-    "ThreadMembersUpdate",
-    "GuildJoin",
-    "GuildUpdate",
-    "GuildLeft",
-    "GuildUnavailable",
+    "ApplicationCommandPermissionsUpdate",
+    "AutocompleteCompletion",
+    "AutocompleteError",
+    "AutoModCreated",
+    "AutoModDeleted",
+    "AutoModExec",
+    "AutoModUpdated",
     "BanCreate",
     "BanRemove",
+    "BaseEvent",
+    "BaseVoiceEvent",
+    "ButtonPressed",
+    "ChannelCreate",
+    "ChannelDelete",
+    "ChannelPinsUpdate",
+    "ChannelUpdate",
+    "CommandCompletion",
+    "CommandError",
+    "Component",
+    "ComponentCompletion",
+    "ComponentError",
+    "Connect",
+    "Disconnect",
+    "Error",
+    "GuildAvailable",
     "GuildEmojisUpdate",
+    "GuildEvent",
+    "GuildJoin",
+    "GuildLeft",
+    "GuildMembersChunk",
     "GuildStickersUpdate",
+    "GuildUnavailable",
+    "GuildUpdate",
+    "IntegrationCreate",
+    "IntegrationDelete",
+    "IntegrationUpdate",
+    "InteractionCreate",
+    "InviteCreate",
+    "InviteDelete",
+    "Login",
     "MemberAdd",
     "MemberRemove",
     "MemberUpdate",
-    "RoleCreate",
-    "RoleUpdate",
-    "RoleDelete",
-    "GuildMembersChunk",
-    "IntegrationCreate",
-    "IntegrationUpdate",
-    "IntegrationDelete",
-    "InviteCreate",
-    "InviteDelete",
     "MessageCreate",
-    "MessageUpdate",
     "MessageDelete",
     "MessageDeleteBulk",
     "MessageReactionAdd",
     "MessageReactionRemove",
     "MessageReactionRemoveAll",
+    "MessageUpdate",
+    "ModalCompletion",
+    "ModalError",
+    "NewThreadCreate",
     "PresenceUpdate",
+    "RawGatewayEvent",
+    "Ready",
+    "Resume",
+    "RoleCreate",
+    "RoleDelete",
+    "RoleUpdate",
+    "Select",
+    "ShardConnect",
+    "ShardDisconnect",
     "StageInstanceCreate",
     "StageInstanceDelete",
     "StageInstanceUpdate",
-    "TypingStart",
-    "WebhooksUpdate",
-    "InteractionCreate",
-    "VoiceStateUpdate",
-    "BaseEvent",
-    "GuildEvent",
-    "Login",
-    "Connect",
-    "Resume",
-    "Disconnect",
     "Startup",
-    "Ready",
+    "ThreadCreate",
+    "ThreadDelete",
+    "ThreadListSync",
+    "ThreadMembersUpdate",
+    "ThreadMemberUpdate",
+    "ThreadUpdate",
+    "TypingStart",
+    "VoiceStateUpdate",
+    "VoiceUserDeafen",
+    "VoiceUserJoin",
+    "VoiceUserLeave",
+    "VoiceUserMove",
+    "VoiceUserMute",
+    "WebhooksUpdate",
     "WebsocketReady",
-    "Component",
-    "Button",
-    "Select",
 )
