@@ -4,7 +4,6 @@ import discord_typings
 
 from naff.client.utils.serializer import dict_filter_none
 from naff.models.naff.protocols import CanRequest
-
 from ..route import Route, PAYLOAD_TYPE
 
 __all__ = ("GuildRequests",)
@@ -133,7 +132,7 @@ class GuildRequests(CanRequest):
         )
         payload = kwargs.copy()
         for key, value in kwargs.items():
-            if key not in expected or value is None:  # todo review
+            if key not in expected or value is None:
                 del payload[key]
 
         # only do the request if there is something to modify
