@@ -2,12 +2,12 @@ from io import IOBase
 from pathlib import Path
 from typing import BinaryIO, Optional, Union
 
-from naff.client.utils.attr_utils import define, field
+import attrs
 
 __all__ = ("File", "open_file", "UPLOADABLE_TYPE")
 
 
-@define(kw_only=False)
+@attrs.define(eq=False, order=False, hash=False, kw_only=False)
 class File:
     """
     Representation of a file.
@@ -16,9 +16,9 @@ class File:
 
     """
 
-    file: Union["IOBase", BinaryIO, "Path", str] = field(repr=True)
+    file: Union["IOBase", BinaryIO, "Path", str] = attrs.field(repr=True)
     """Location of file to send or the bytes."""
-    file_name: Optional[str] = field(repr=True, default=None)
+    file_name: Optional[str] = attrs.field(repr=True, default=None)
     """Set a filename that will be displayed when uploaded to discord. If you leave this empty, the file will be called `file` by default"""
 
     def open_file(self) -> BinaryIO:
