@@ -6,15 +6,19 @@ from functools import cmp_to_key
 from typing import List, Optional, Union, Set, Dict, Any, TYPE_CHECKING
 from warnings import warn
 
+import attrs
+
 import naff.models as models
-from naff.client.const import MISSING, PREMIUM_GUILD_LIMITS, logger, Absent
+from naff.client.const import Absent, MISSING, PREMIUM_GUILD_LIMITS
 from naff.client.errors import EventLocationNotProvided, NotFound
 from naff.client.mixins.serialization import DictSerializationMixin
 from naff.client.utils.attr_converters import optional
 from naff.client.utils.attr_converters import timestamp_converter
-from naff.client.utils.attr_utils import define, field, docs
+from naff.client.utils.attr_utils import docs
 from naff.client.utils.deserialise_app_cmds import deserialize_app_cmds
 from naff.client.utils.serializer import to_image_data, no_export_meta
+from naff.models.discord.app_perms import CommandPermissions, ApplicationCommandPermission
+from naff.models.discord.auto_mod import AutoModRule, BaseAction, BaseTrigger
 from naff.models.discord.file import UPLOADABLE_TYPE
 from naff.models.misc.iterator import AsyncIterator
 from .base import DiscordObject, ClientObject
@@ -34,7 +38,6 @@ from .enums import (
     AutoModEvent,
     AutoModTriggerType,
 )
-from naff.models.discord.auto_mod import AutoModRule, BaseAction, BaseTrigger
 from .snowflake import to_snowflake, Snowflake_Type, to_optional_snowflake, to_snowflake_list
 
 if TYPE_CHECKING:
@@ -59,7 +62,7 @@ __all__ = (
 )
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class GuildBan:
     reason: Optional[str]
     """The reason for the ban"""
@@ -67,20 +70,20 @@ class GuildBan:
     """The banned user"""
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class BaseGuild(DiscordObject):
-    name: str = field(repr=True)
+    name: str = attrs.field(repr=True)
     """Name of guild. (2-100 characters, excluding trailing and leading whitespace)"""
-    description: Optional[str] = field(repr=True, default=None)
+    description: Optional[str] = attrs.field(repr=True, default=None)
     """The description for the guild, if the guild is discoverable"""
 
-    icon: Optional["models.Asset"] = field(default=None)
+    icon: Optional["models.Asset"] = attrs.field(repr=False, default=None)
     """Icon image asset"""
-    splash: Optional["models.Asset"] = field(default=None)
+    splash: Optional["models.Asset"] = attrs.field(repr=False, default=None)
     """Splash image asset"""
-    discovery_splash: Optional["models.Asset"] = field(default=None)
+    discovery_splash: Optional["models.Asset"] = attrs.field(repr=False, default=None)
     """Discovery splash image. Only present for guilds with the "DISCOVERABLE" feature."""
-    features: List[str] = field(factory=list)
+    features: List[str] = attrs.field(repr=False, factory=list)
     """The features of this guild"""
 
     @classmethod
@@ -96,23 +99,25 @@ class BaseGuild(DiscordObject):
         return data
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class GuildWelcome(ClientObject):
-    description: Optional[str] = field(default=None, metadata=docs("Welcome Screen server description"))
-    welcome_channels: List["models.GuildWelcomeChannel"] = field(
-        metadata=docs("List of Welcome Channel objects, up to 5")
+    description: Optional[str] = attrs.field(
+        repr=False, default=None, metadata=docs("Welcome Screen server description")
+    )
+    welcome_channels: List["models.GuildWelcomeChannel"] = attrs.field(
+        repr=False, metadata=docs("List of Welcome Channel objects, up to 5")
     )
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class GuildPreview(BaseGuild):
     """A partial guild object."""
 
-    emoji: list["models.PartialEmoji"] = field(factory=list)
+    emoji: list["models.PartialEmoji"] = attrs.field(repr=False, factory=list)
     """A list of custom emoji from this guild"""
-    approximate_member_count: int = field(default=0)
+    approximate_member_count: int = attrs.field(repr=False, default=0)
     """Approximate number of members in this guild"""
-    approximate_presence_count: int = field(default=0)
+    approximate_presence_count: int = attrs.field(repr=False, default=0)
     """Approximate number of online members in this guild"""
 
     @classmethod
@@ -140,85 +145,92 @@ class MemberIterator(AsyncIterator):
         raise QueueEmpty
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class Guild(BaseGuild):
     """Guilds in Discord represent an isolated collection of users and channels, and are often referred to as "servers" in the UI."""
 
-    unavailable: bool = field(default=False)
+    unavailable: bool = attrs.field(repr=False, default=False)
     """True if this guild is unavailable due to an outage."""
-    # owner: bool = field(default=False)  # we get this from api but it's kinda useless to store
-    afk_channel_id: Optional[Snowflake_Type] = field(default=None)
+    # owner: bool = attrs.field(repr=False, default=False)  # we get this from api but it's kinda useless to store
+    afk_channel_id: Optional[Snowflake_Type] = attrs.field(repr=False, default=None)
     """The channel id for afk."""
-    afk_timeout: Optional[int] = field(default=None)
+    afk_timeout: Optional[int] = attrs.field(repr=False, default=None)
     """afk timeout in seconds."""
-    widget_enabled: bool = field(default=False)
+    widget_enabled: bool = attrs.field(repr=False, default=False)
     """True if the server widget is enabled."""
-    widget_channel_id: Optional[Snowflake_Type] = field(default=None)
+    widget_channel_id: Optional[Snowflake_Type] = attrs.field(repr=False, default=None)
     """The channel id that the widget will generate an invite to, or None if set to no invite."""
-    verification_level: Union[VerificationLevels, int] = field(default=VerificationLevels.NONE)
+    verification_level: Union[VerificationLevels, int] = attrs.field(repr=False, default=VerificationLevels.NONE)
     """The verification level required for the guild."""
-    default_message_notifications: Union[DefaultNotificationLevels, int] = field(
-        default=DefaultNotificationLevels.ALL_MESSAGES
+    default_message_notifications: Union[DefaultNotificationLevels, int] = attrs.field(
+        repr=False, default=DefaultNotificationLevels.ALL_MESSAGES
     )
     """The default message notifications level."""
-    explicit_content_filter: Union[ExplicitContentFilterLevels, int] = field(
-        default=ExplicitContentFilterLevels.DISABLED
+    explicit_content_filter: Union[ExplicitContentFilterLevels, int] = attrs.field(
+        repr=False, default=ExplicitContentFilterLevels.DISABLED
     )
     """The explicit content filter level."""
-    mfa_level: Union[MFALevels, int] = field(default=MFALevels.NONE)
+    mfa_level: Union[MFALevels, int] = attrs.field(repr=False, default=MFALevels.NONE)
     """The required MFA (Multi Factor Authentication) level for the guild."""
-    system_channel_id: Optional[Snowflake_Type] = field(default=None)
+    system_channel_id: Optional[Snowflake_Type] = attrs.field(repr=False, default=None)
     """The id of the channel where guild notices such as welcome messages and boost events are posted."""
-    system_channel_flags: SystemChannelFlags = field(default=SystemChannelFlags.NONE, converter=SystemChannelFlags)
+    system_channel_flags: SystemChannelFlags = attrs.field(
+        repr=False, default=SystemChannelFlags.NONE, converter=SystemChannelFlags
+    )
     """The system channel flags."""
-    rules_channel_id: Optional[Snowflake_Type] = field(default=None)
+    rules_channel_id: Optional[Snowflake_Type] = attrs.field(repr=False, default=None)
     """The id of the channel where Community guilds can display rules and/or guidelines."""
-    joined_at: str = field(default=None, converter=optional(timestamp_converter))
+    joined_at: str = attrs.field(repr=False, default=None, converter=optional(timestamp_converter))
     """When this guild was joined at."""
-    large: bool = field(default=False)
+    large: bool = attrs.field(repr=False, default=False)
     """True if this is considered a large guild."""
-    member_count: int = field(default=0)
+    member_count: int = attrs.field(repr=False, default=0)
     """The total number of members in this guild."""
-    presences: List[dict] = field(factory=list)
+    presences: List[dict] = attrs.field(repr=False, factory=list)
     """The presences of the members in the guild, will only include non-offline members if the size is greater than large threshold."""
-    max_presences: Optional[int] = field(default=None)
+    max_presences: Optional[int] = attrs.field(repr=False, default=None)
     """The maximum number of presences for the guild. (None is always returned, apart from the largest of guilds)"""
-    max_members: Optional[int] = field(default=None)
+    max_members: Optional[int] = attrs.field(repr=False, default=None)
     """The maximum number of members for the guild."""
-    vanity_url_code: Optional[str] = field(default=None)
+    vanity_url_code: Optional[str] = attrs.field(repr=False, default=None)
     """The vanity url code for the guild."""
-    banner: Optional[str] = field(default=None)
+    banner: Optional[str] = attrs.field(repr=False, default=None)
     """Hash for banner image."""
-    premium_tier: Optional[str] = field(default=None)
+    premium_tier: Optional[str] = attrs.field(repr=False, default=None)
     """The premium tier level. (Server Boost level)"""
-    premium_subscription_count: int = field(default=0)
+    premium_subscription_count: int = attrs.field(repr=False, default=0)
     """The number of boosts this guild currently has."""
-    preferred_locale: str = field()
+    preferred_locale: str = attrs.field(
+        repr=False,
+    )
     """The preferred locale of a Community guild. Used in server discovery and notices from Discord. Defaults to \"en-US\""""
-    public_updates_channel_id: Optional[Snowflake_Type] = field(default=None)
+    public_updates_channel_id: Optional[Snowflake_Type] = attrs.field(repr=False, default=None)
     """The id of the channel where admins and moderators of Community guilds receive notices from Discord."""
-    max_video_channel_users: int = field(default=0)
+    max_video_channel_users: int = attrs.field(repr=False, default=0)
     """The maximum amount of users in a video channel."""
-    welcome_screen: Optional["GuildWelcome"] = field(default=None)
+    welcome_screen: Optional["GuildWelcome"] = attrs.field(repr=False, default=None)
     """The welcome screen of a Community guild, shown to new members, returned in an Invite's guild object."""
-    nsfw_level: Union[NSFWLevels, int] = field(default=NSFWLevels.DEFAULT)
+    nsfw_level: Union[NSFWLevels, int] = attrs.field(repr=False, default=NSFWLevels.DEFAULT)
     """The guild NSFW level."""
-    stage_instances: List[dict] = field(factory=list)  # TODO stage instance objects
+    stage_instances: List[dict] = attrs.field(repr=False, factory=list)  # TODO stage instance objects
     """Stage instances in the guild."""
-    chunked = field(factory=asyncio.Event, metadata=no_export_meta)
+    chunked = attrs.field(repr=False, factory=asyncio.Event, metadata=no_export_meta)
     """An event that is fired when this guild has been chunked"""
+    command_permissions: dict[Snowflake_Type, CommandPermissions] = attrs.field(
+        repr=False, factory=dict, metadata=no_export_meta
+    )
+    """A cache of all command permissions for this guild"""
 
-    _owner_id: Snowflake_Type = field(converter=to_snowflake)
-    _channel_ids: Set[Snowflake_Type] = field(factory=set)
-    _thread_ids: Set[Snowflake_Type] = field(factory=set)
-    _member_ids: Set[Snowflake_Type] = field(factory=set)
-    _role_ids: Set[Snowflake_Type] = field(factory=set)
-    _chunk_cache: list = field(factory=list)
-    _channel_gui_positions: Dict[Snowflake_Type, int] = field(factory=dict)
+    _owner_id: Snowflake_Type = attrs.field(repr=False, converter=to_snowflake)
+    _channel_ids: Set[Snowflake_Type] = attrs.field(repr=False, factory=set)
+    _thread_ids: Set[Snowflake_Type] = attrs.field(repr=False, factory=set)
+    _member_ids: Set[Snowflake_Type] = attrs.field(repr=False, factory=set)
+    _role_ids: Set[Snowflake_Type] = attrs.field(repr=False, factory=set)
+    _chunk_cache: list = attrs.field(repr=False, factory=list)
+    _channel_gui_positions: Dict[Snowflake_Type, int] = attrs.field(repr=False, factory=dict)
 
     @classmethod
     def _process_dict(cls, data: Dict[str, Any], client: "Client") -> Dict[str, Any]:
-        # todo: find a away to prevent this loop from blocking the event loop
         data = super()._process_dict(data, client)
         guild_id = data["id"]
 
@@ -314,7 +326,8 @@ class Guild(BaseGuild):
     @property
     def channels(self) -> List["models.TYPE_GUILD_CHANNEL"]:
         """Returns a list of channels associated with this guild."""
-        return [self._client.cache.get_channel(c_id) for c_id in self._channel_ids]
+        channels = [self._client.cache.get_channel(c_id) for c_id in self._channel_ids]
+        return [c for c in channels if c]
 
     @property
     def threads(self) -> List["models.TYPE_THREAD_CHANNEL"]:
@@ -489,6 +502,26 @@ class Guild(BaseGuild):
         data = await self._client.http.get_guild_channels(self.id)
         return [self._client.cache.place_channel_data(channel_data) for channel_data in data]
 
+    async def fetch_app_cmd_perms(self) -> dict[Snowflake_Type, "CommandPermissions"]:
+        """
+        Fetch the application command permissions for this guild.
+
+        Returns:
+            The application command permissions for this guild.
+
+        """
+        data = await self._client.http.batch_get_application_command_permissions(self._client.app.id, self.id)
+
+        for command in data:
+            command_permissions = CommandPermissions(client=self._client, command_id=command["id"], guild=self)
+            perms = [ApplicationCommandPermission.from_dict(perm, self) for perm in command["permissions"]]
+
+            command_permissions.update_permissions(*perms)
+
+            self.command_permissions[int(command["id"])] = command_permissions
+
+        return self.command_permissions
+
     def is_owner(self, user: Snowflake_Type) -> bool:
         """
         Whether the user is owner of the guild.
@@ -528,7 +561,7 @@ class Guild(BaseGuild):
             self._client.cache.place_member_data(self.id, member)
 
         self.chunked.set()
-        logger.info(
+        self.logger.info(
             f"Cached {iterator.total_retrieved} members for {self.id} in {time.perf_counter() - start_time:.2f} seconds"
         )
 
@@ -596,10 +629,10 @@ class Guild(BaseGuild):
             self._chunk_cache = self._chunk_cache + chunk.get("members")
 
         if chunk.get("chunk_index") != chunk.get("chunk_count") - 1:
-            return logger.debug(f"Cached chunk of {len(chunk.get('members'))} members for {self.id}")
+            return self.logger.debug(f"Cached chunk of {len(chunk.get('members'))} members for {self.id}")
         else:
             members = self._chunk_cache
-            logger.info(f"Processing {len(members)} members for {self.id}")
+            self.logger.info(f"Processing {len(members)} members for {self.id}")
 
             s = time.monotonic()
             start_time = time.perf_counter()
@@ -615,7 +648,7 @@ class Guild(BaseGuild):
 
             total_time = time.perf_counter() - start_time
             self.chunk_cache = []
-            logger.info(f"Cached members for {self.id} in {total_time:.2f} seconds")
+            self.logger.info(f"Cached members for {self.id} in {total_time:.2f} seconds")
             self.chunked.set()
 
     async def fetch_audit_log(
@@ -683,6 +716,7 @@ class Guild(BaseGuild):
 
     async def edit(
         self,
+        *,
         name: Absent[Optional[str]] = MISSING,
         description: Absent[Optional[str]] = MISSING,
         verification_level: Absent[Optional["VerificationLevels"]] = MISSING,
@@ -1972,24 +2006,34 @@ class Guild(BaseGuild):
         return sorted_channels
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class GuildTemplate(ClientObject):
-    code: str = field(repr=True, metadata=docs("the template code (unique ID)"))
-    name: str = field(repr=True, metadata=docs("the name"))
-    description: Optional[str] = field(default=None, metadata=docs("the description"))
+    code: str = attrs.field(repr=True, metadata=docs("the template code (unique ID)"))
+    name: str = attrs.field(repr=True, metadata=docs("the name"))
+    description: Optional[str] = attrs.field(repr=False, default=None, metadata=docs("the description"))
 
-    usage_count: int = field(default=0, metadata=docs("number of times this template has been used"))
+    usage_count: int = attrs.field(repr=False, default=0, metadata=docs("number of times this template has been used"))
 
-    creator_id: Snowflake_Type = field(metadata=docs("The ID of the user who created this template"))
-    creator: Optional["models.User"] = field(default=None, metadata=docs("the user who created this template"))
+    creator_id: Snowflake_Type = attrs.field(repr=False, metadata=docs("The ID of the user who created this template"))
+    creator: Optional["models.User"] = attrs.field(
+        repr=False, default=None, metadata=docs("the user who created this template")
+    )
 
-    created_at: "models.Timestamp" = field(metadata=docs("When this template was created"))
-    updated_at: "models.Timestamp" = field(metadata=docs("When this template was last synced to the source guild"))
+    created_at: "models.Timestamp" = attrs.field(repr=False, metadata=docs("When this template was created"))
+    updated_at: "models.Timestamp" = attrs.field(
+        repr=False, metadata=docs("When this template was last synced to the source guild")
+    )
 
-    source_guild_id: Snowflake_Type = field(metadata=docs("The ID of the guild this template is based on"))
-    guild_snapshot: "models.Guild" = field(metadata=docs("A snapshot of the guild this template contains"))
+    source_guild_id: Snowflake_Type = attrs.field(
+        repr=False, metadata=docs("The ID of the guild this template is based on")
+    )
+    guild_snapshot: "models.Guild" = attrs.field(
+        repr=False, metadata=docs("A snapshot of the guild this template contains")
+    )
 
-    is_dirty: bool = field(default=False, metadata=docs("Whether this template has un-synced changes"))
+    is_dirty: bool = attrs.field(
+        repr=False, default=False, metadata=docs("Whether this template has un-synced changes")
+    )
 
     @classmethod
     def _process_dict(cls, data: Dict[str, Any], client: "Client") -> Dict[str, Any]:
@@ -2028,48 +2072,54 @@ class GuildTemplate(ClientObject):
         await self._client.http.delete_guild_template(self.source_guild_id, self.code)
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class GuildWelcomeChannel(ClientObject):
-    channel_id: Snowflake_Type = field(repr=True, metadata=docs("Welcome Channel ID"))
-    description: str = field(metadata=docs("Welcome Channel description"))
-    emoji_id: Optional[Snowflake_Type] = field(
-        default=None, metadata=docs("Welcome Channel emoji ID if the emoji is custom")
+    channel_id: Snowflake_Type = attrs.field(repr=True, metadata=docs("Welcome Channel ID"))
+    description: str = attrs.field(repr=False, metadata=docs("Welcome Channel description"))
+    emoji_id: Optional[Snowflake_Type] = attrs.field(
+        repr=False, default=None, metadata=docs("Welcome Channel emoji ID if the emoji is custom")
     )
-    emoji_name: Optional[str] = field(
-        default=None, metadata=docs("Emoji name if custom, unicode character if standard")
+    emoji_name: Optional[str] = attrs.field(
+        repr=False, default=None, metadata=docs("Emoji name if custom, unicode character if standard")
     )
 
 
 class GuildIntegration(DiscordObject):
-    name: str = field(repr=True)
+    name: str = attrs.field(repr=True)
     """The name of the integration"""
-    type: str = field(repr=True)
+    type: str = attrs.field(repr=True)
     """integration type (twitch, youtube, or discord)"""
-    enabled: bool = field(repr=True)
+    enabled: bool = attrs.field(repr=True)
     """is this integration enabled"""
-    account: dict = field()
+    account: dict = attrs.field(
+        repr=False,
+    )
     """integration account information"""
-    application: Optional["models.Application"] = field(default=None)
+    application: Optional["models.Application"] = attrs.field(repr=False, default=None)
     """The bot/OAuth2 application for discord integrations"""
-    _guild_id: Snowflake_Type = field()
+    _guild_id: Snowflake_Type = attrs.field(
+        repr=False,
+    )
 
-    syncing: Optional[bool] = field(default=MISSING)
+    syncing: Optional[bool] = attrs.field(repr=False, default=MISSING)
     """is this integration syncing"""
-    role_id: Optional[Snowflake_Type] = field(default=MISSING)
+    role_id: Optional[Snowflake_Type] = attrs.field(repr=False, default=MISSING)
     """id that this integration uses for "subscribers\""""
-    enable_emoticons: bool = field(default=MISSING)
+    enable_emoticons: bool = attrs.field(repr=False, default=MISSING)
     """whether emoticons should be synced for this integration (twitch only currently)"""
-    expire_behavior: IntegrationExpireBehaviour = field(default=MISSING, converter=optional(IntegrationExpireBehaviour))
+    expire_behavior: IntegrationExpireBehaviour = attrs.field(
+        repr=False, default=MISSING, converter=optional(IntegrationExpireBehaviour)
+    )
     """the behavior of expiring subscribers"""
-    expire_grace_period: int = field(default=MISSING)
+    expire_grace_period: int = attrs.field(repr=False, default=MISSING)
     """the grace period (in days) before expiring subscribers"""
-    user: "models.BaseUser" = field(default=MISSING)
+    user: "models.BaseUser" = attrs.field(repr=False, default=MISSING)
     """user for this integration"""
-    synced_at: "models.Timestamp" = field(default=MISSING, converter=optional(timestamp_converter))
+    synced_at: "models.Timestamp" = attrs.field(repr=False, default=MISSING, converter=optional(timestamp_converter))
     """when this integration was last synced"""
-    subscriber_count: int = field(default=MISSING)
+    subscriber_count: int = attrs.field(repr=False, default=MISSING)
     """how many subscribers this integration has"""
-    revoked: bool = field(default=MISSING)
+    revoked: bool = attrs.field(repr=False, default=MISSING)
     """has this integration been revoked"""
 
     @classmethod
@@ -2087,23 +2137,23 @@ class GuildIntegration(DiscordObject):
 
 
 class GuildWidgetSettings(DictSerializationMixin):
-    enabled: bool = field(repr=True, default=False)
+    enabled: bool = attrs.field(repr=True, default=False)
     """Whether the widget is enabled."""
-    channel_id: Optional["Snowflake_Type"] = field(repr=True, default=None, converter=to_optional_snowflake)
+    channel_id: Optional["Snowflake_Type"] = attrs.field(repr=True, default=None, converter=to_optional_snowflake)
     """The widget channel id. None if widget is not enabled."""
 
 
 class GuildWidget(DiscordObject):
-    name: str = field(repr=True)
+    name: str = attrs.field(repr=True)
     """Guild name (2-100 characters)"""
-    instant_invite: str = field(repr=True, default=None)
+    instant_invite: str = attrs.field(repr=True, default=None)
     """Instant invite for the guilds specified widget invite channel"""
-    presence_count: int = field(repr=True, default=0)
+    presence_count: int = attrs.field(repr=True, default=0)
     """Number of online members in this guild"""
 
-    _channel_ids: List["Snowflake_Type"] = field(default=[])
+    _channel_ids: List["Snowflake_Type"] = attrs.field(repr=False, default=[])
     """Voice and stage channels which are accessible by @everyone"""
-    _member_ids: List["Snowflake_Type"] = field(default=[])
+    _member_ids: List["Snowflake_Type"] = attrs.field(repr=False, default=[])
     """Special widget user objects that includes users presence (Limit 100)"""
 
     @classmethod
@@ -2155,29 +2205,29 @@ class GuildWidget(DiscordObject):
         return [await self._client.fetch_user(member_id) for member_id in self._member_ids]
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class AuditLogChange(ClientObject):
-    key: str = field(repr=True)
+    key: str = attrs.field(repr=True)
     """name of audit log change key"""
-    new_value: Optional[Union[list, str, int, bool, "Snowflake_Type"]] = field(default=MISSING)
+    new_value: Optional[Union[list, str, int, bool, "Snowflake_Type"]] = attrs.field(repr=False, default=MISSING)
     """new value of the key"""
-    old_value: Optional[Union[list, str, int, bool, "Snowflake_Type"]] = field(default=MISSING)
+    old_value: Optional[Union[list, str, int, bool, "Snowflake_Type"]] = attrs.field(repr=False, default=MISSING)
     """old value of the key"""
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class AuditLogEntry(DiscordObject):
-    target_id: Optional["Snowflake_Type"] = field(converter=optional(to_snowflake))
+    target_id: Optional["Snowflake_Type"] = attrs.field(repr=False, converter=optional(to_snowflake))
     """id of the affected entity (webhook, user, role, etc.)"""
-    user_id: "Snowflake_Type" = field(converter=optional(to_snowflake))
+    user_id: "Snowflake_Type" = attrs.field(repr=False, converter=optional(to_snowflake))
     """the user who made the changes"""
-    action_type: "AuditLogEventType" = field(converter=AuditLogEventType)
+    action_type: "AuditLogEventType" = attrs.field(repr=False, converter=AuditLogEventType)
     """type of action that occurred"""
-    changes: Optional[List[AuditLogChange]] = field(default=MISSING)
+    changes: Optional[List[AuditLogChange]] = attrs.field(repr=False, default=MISSING)
     """changes made to the target_id"""
-    options: Optional[Union["Snowflake_Type", str]] = field(default=MISSING)
+    options: Optional[Union["Snowflake_Type", str]] = attrs.field(repr=False, default=MISSING)
     """additional info for certain action types"""
-    reason: Optional[str] = field(default=MISSING)
+    reason: Optional[str] = attrs.field(repr=False, default=MISSING)
     """the reason for the change (0-512 characters)"""
 
     @classmethod
@@ -2188,23 +2238,25 @@ class AuditLogEntry(DiscordObject):
         return data
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class AuditLog(ClientObject):
     """Contains entries and other data given from selected"""
 
-    application_commands: list["InteractionCommand"] = field(factory=list, converter=optional(deserialize_app_cmds))
+    application_commands: list["InteractionCommand"] = attrs.field(
+        repr=False, factory=list, converter=optional(deserialize_app_cmds)
+    )
     """list of application commands that have had their permissions updated"""
-    entries: Optional[List["AuditLogEntry"]] = field(default=MISSING)
+    entries: Optional[List["AuditLogEntry"]] = attrs.field(repr=False, default=MISSING)
     """list of audit log entries"""
-    scheduled_events: Optional[List["models.ScheduledEvent"]] = field(default=MISSING)
+    scheduled_events: Optional[List["models.ScheduledEvent"]] = attrs.field(repr=False, default=MISSING)
     """list of guild scheduled events found in the audit log"""
-    integrations: Optional[List["GuildIntegration"]] = field(default=MISSING)
+    integrations: Optional[List["GuildIntegration"]] = attrs.field(repr=False, default=MISSING)
     """list of partial integration objects"""
-    threads: Optional[List["models.ThreadChannel"]] = field(default=MISSING)
+    threads: Optional[List["models.ThreadChannel"]] = attrs.field(repr=False, default=MISSING)
     """list of threads found in the audit log"""
-    users: Optional[List["models.User"]] = field(default=MISSING)
+    users: Optional[List["models.User"]] = attrs.field(repr=False, default=MISSING)
     """list of users found in the audit log"""
-    webhooks: Optional[List["models.Webhook"]] = field(default=MISSING)
+    webhooks: Optional[List["models.Webhook"]] = attrs.field(repr=False, default=MISSING)
     """list of webhooks found in the audit log"""
 
     @classmethod
