@@ -1,8 +1,9 @@
 import asyncio
 from typing import TYPE_CHECKING
 
+import attrs
+
 from naff.client.errors import AlreadyDeferred, NotFound, BadRequest, HTTPException
-from naff.client.utils.attr_utils import define, field
 
 if TYPE_CHECKING:
     from naff.models.naff.context import InteractionContext
@@ -10,17 +11,17 @@ if TYPE_CHECKING:
 __all__ = ("AutoDefer",)
 
 
-@define()
+@attrs.define(eq=False, order=False, hash=False, kw_only=True)
 class AutoDefer:
     """Automatically defer application commands for you!"""
 
-    enabled: bool = field(default=False)
+    enabled: bool = attrs.field(repr=False, default=False)
     """Whether or not auto-defer is enabled"""
 
-    ephemeral: bool = field(default=False)
+    ephemeral: bool = attrs.field(repr=False, default=False)
     """Should the command be deferred as ephemeral or not"""
 
-    time_until_defer: float = field(default=1.5)
+    time_until_defer: float = attrs.field(repr=False, default=1.5)
     """How long to wait before automatically deferring"""
 
     async def __call__(self, ctx: "InteractionContext") -> None:
