@@ -1,4 +1,4 @@
-from naff import InteractionContext, PrefixedContext, SendableContext
+from naff import InteractionContext, PrefixedContext, HybridContext, SendableContext
 from typeguard import check_type
 
 __all__ = ()
@@ -7,3 +7,4 @@ __all__ = ()
 def test_sendable_context() -> None:
     check_type("prefixed_context", PrefixedContext, SendableContext)
     check_type("interaction_context", InteractionContext, SendableContext)
+    check_type("hybrid_context", HybridContext, SendableContext)
